import axios from 'axios'
import { showFailToast, showLoadingToast, closeToast } from 'vant'

const baseAxios = axios.create({
    baseURL: '',
    timeout: 20000,
})

// 加载标志计数
let loadingList = 0

export function fetchBase({
    url = '',
    // 需要携带在url上的参数
    params,
    // 请求体body的参数
    body = {},
    method = 'POST',
    contentType = 'json',
    loading = false
} = {}) {
    contentType === 'form' && (contentType = 'application/x-www-form-urlencoded')
    contentType === 'json' && (contentType = 'application/json; charset=utf-8')
    contentType === 'file' && (contentType = 'multipart/form-data')

    return new Promise((resolve, reject) => {
        if (loading) {
            loadingList++
            showLoadingToast({ message: '加载中...', forbidClick: true, duration: 0 })
        }
        baseAxios({
            method: method,
            url: `/tumour-admin${url}`,
            params: params,
            data: body,
            headers: {
                'Content-Type': contentType
            }
        }).then(function (response) {
            const data = response.data || {}
            if (data.code !== 'SUCCESS') {
                showFailToast('请求失败')
                reject(data)
                return
            }
            resolve(data)
        }).catch(function (err) {
            showFailToast('请求失败')
            reject(err)
        }).finally(() => {
            if (loading) {
                loadingList--
                if (loadingList <= 0) {
                    closeToast()
                }
            }
        })
    })
}
